@@ -1,11 +1,11 @@
 <?php
 /**
- * $Horde: imp/folders.php,v 2.309 2004/12/22 07:13:00 slusarz Exp $
+ * $Horde: imp/folders.php,v 2.309.2.35 2007/01/02 13:54:54 jan Exp $
  *
- * Copyright 2000-2004 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 2000-2004 Jon Parise <jon@horde.org>
- * Copyright 2000-2004 Anil Madhavapeddy <avsm@horde.org>
- * Copyright 2003-2004 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2000-2007 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 2000-2007 Jon Parise <jon@horde.org>
+ * Copyright 2000-2007 Anil Madhavapeddy <avsm@horde.org>
+ * Copyright 2003-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -13,12 +13,6 @@
 
 /**
  * Utility function to return a url for the various images.
- *
- * @param string $name  Image filename.
- * @param string $alt   Image alt tag.
- * @param string $type  Either 'folder' or 'tree'.
- *
- * @return string  Link to the folder image.
  */
 function _image($name, $alt, $type)
 {
@@ -39,13 +33,14 @@ function _image($name, $alt, $type)
     return $cache[$type][$name];
 }
 
-$authentication = OP_HALFOPEN;
 @define('IMP_BASE', dirname(__FILE__));
+$authentication = OP_HALFOPEN;
 require_once IMP_BASE . '/lib/base.php';
 require_once IMP_BASE . '/lib/IMAP/Tree.php';
 require_once IMP_BASE . '/lib/Folder.php';
 require_once 'Horde/Identity.php';
 require_once 'Horde/Template.php';
+Horde::addScriptFile('folders.js', 'imp');
 
 /* Redirect back to the mailbox if folder use is not allowed. */
 if (!$conf['user']['allow_folders']) {
@@ -72,7 +67,7 @@ $subscribe = $prefs->getValue('subscribe');
 $showAll = (!$subscribe || $imp['showunsub']);
 
 /* Get the base URL for this page. */
-$folders_url = Horde::selfURL();
+$folders_url = Horde::selfUrl();
 
 /* Initialize the IMP_Folder object. */
 $imp_folder = &IMP_Folder::singleton();
@@ -102,36 +97,35 @@ case 'collapse_all_folders':
     $imptree->collapseAll();
     break;
 
-case 'refresh_folders':
+case 'rebuild_tree':
     $imptree->init();
     break;
 
 case 'expunge_folder':
     if (!empty($folder_list)) {
         require_once IMP_BASE . '/lib/Message.php';
-        $imp_message = &new IMP_Message();
+        $imp_message = &IMP_Message::singleton();
         $imp_message->expungeMailbox($folder_list);
     }
     break;
 
 case 'delete_folder':
     if (!empty($folder_list)) {
-        $imp_folder->delete($imp['stream'], $folder_list, $subscribe);
+        $imp_folder->delete($folder_list, $subscribe);
     }
     break;
 
-case 'delete_vfolder':
-    $vfolder = Util::getFormData('vfolder');
-    if (!empty($vfolder)) {
-        IMP_VFolder::deleteVFolder($vfolder);
-        $imptree->delete($vfolder);
+case 'delete_search_query':
+    $queryid = Util::getFormData('queryid');
+    if (!empty($queryid)) {
+        $imp_search->deleteSearchQuery($queryid);
     }
     break;
 
 case 'download_folder':
 case 'download_folder_zip':
     if (!empty($folder_list)) {
-        $mbox = $imp_folder->generateMbox($imp['stream'], $folder_list, false);
+        $mbox = $imp_folder->generateMbox($folder_list, false);
         if ($actionID == 'download_folder') {
             $browser->downloadHeaders($folder_list[0] . '.mbox', null, false, strlen($mbox));
         } else {
@@ -150,7 +144,7 @@ case 'import_mbox':
     if (!empty($import_folder)) {
         $res = Browser::wasFileUploaded('mbox_upload', _("mailbox file"));
         if (!is_a($res, 'PEAR_Error')) {
-            $res = $imp_folder->importMbox($imp['stream'], $import_folder, $_FILES['mbox_upload']['tmp_name']);
+            $res = $imp_folder->importMbox($import_folder, $_FILES['mbox_upload']['tmp_name']);
             if ($res === false) {
                 $notification->push(sprintf(_("There was an error importing %s."), basename($_FILES['mbox_upload']['name'])), 'horde.error');
             } else {
@@ -170,12 +164,12 @@ case 'create_folder':
     if (!empty($new_mailbox)) {
         $new_mailbox = String::convertCharset($new_mailbox, NLS::getCharset(), 'UTF7-IMAP');
         if (count($folder_list) == 1) {
-            $new_mailbox = $folder_list[0] . $imp['delimiter'] . $new_mailbox;
-        } elseif (!empty($imp['folders'])) {
-            $new_mailbox = $imp['folders'] . $new_mailbox;
+            $namespace_info = IMP::getNamespace($folder_list[0]);
+            $new_mailbox = $folder_list[0] . $namespace_info['delimiter'] . $new_mailbox;
+        } else {
+            $new_mailbox = IMP::appendNamespace($new_mailbox);
         }
-
-        $imp_folder->create($imp['stream'], $new_mailbox, $subscribe);
+        $imp_folder->create($new_mailbox, $subscribe);
     }
     break;
 
@@ -189,8 +183,8 @@ case 'rename_folder':
         for ($i = 0; $i < $iMax; $i++) {
             $oldname = trim($old_names[$i], "\r\n");
             $newname = trim($new_names[$i], "\r\n");
-            $newname = IMP::addPreambleString(String::convertCharset($newname, NLS::getCharset(), 'UTF7-IMAP'));
-            $imp_folder->rename($imp['stream'], $oldname, $newname);
+            $newname = String::convertCharset($newname, NLS::getCharset(), 'UTF7-IMAP');
+            $imp_folder->rename($oldname, IMP::appendNamespace($newname));
         }
     }
     break;
@@ -199,9 +193,9 @@ case 'subscribe_folder':
 case 'unsubscribe_folder':
     if (!empty($folder_list)) {
         if ($actionID == 'subscribe_folder') {
-            $imp_folder->subscribe($imp['stream'], $folder_list);
+            $imp_folder->subscribe($folder_list);
         } else {
-            $imp_folder->unsubscribe($imp['stream'], $folder_list);
+            $imp_folder->unsubscribe($folder_list);
         }
     } else {
         $notification->push(_("No folders were specified"), 'horde.message');
@@ -219,19 +213,21 @@ case 'toggle_subscribed_view':
 case 'poll_folder':
     if (!empty($folder_list)) {
         $imptree->addPollList($folder_list);
+        $imp_search->createVINBOXFolder();
     }
     break;
 
 case 'nopoll_folder':
     if (!empty($folder_list)) {
         $imptree->removePollList($folder_list);
+        $imp_search->createVINBOXFolder();
     }
     break;
 
 case 'folders_empty_mailbox':
     if (!empty($folder_list)) {
         include_once IMP_BASE . '/lib/Message.php';
-        $imp_message = &new IMP_Message();
+        $imp_message = &IMP_Message::singleton();
         $imp_message->emptyMailbox($folder_list);
     }
     break;
@@ -240,7 +236,7 @@ case 'mark_folder_seen':
 case 'mark_folder_unseen':
     if (!empty($folder_list)) {
         include_once IMP_BASE . '/lib/Message.php';
-        $imp_message = &new IMP_Message();
+        $imp_message = &IMP_Message::singleton();
         $imp_message->flagAllInMailbox("\\SEEN", $folder_list, ($actionID == 'mark_folder_seen'));
     }
     break;
@@ -248,6 +244,39 @@ case 'mark_folder_unseen':
 case 'login_compose':
     $open_compose_window = IMP::openComposeWin();
     break;
+
+case 'delete_folder_confirm':
+case 'folders_empty_mailbox_confirm':
+    if (!empty($folder_list)) {
+        $title = _("Folder Actions - Confirmation");
+        require IMP_TEMPLATES . '/common-header.inc';
+        require IMP_TEMPLATES . '/menu.inc';
+
+        $loop = array();
+        $rowct = 0;
+
+        foreach ($folder_list as $val) {
+            $data = array(
+                'class' => (++$rowct % 2) ? 'item0' : 'item1',
+                'name' => IMP::displayFolder($val),
+                'val' => $val
+            );
+            $loop[] = $data;
+        }
+
+        $template = &new Horde_Template();
+        $template->setOption('gettext', true);
+        $template->set('cancel', _("Cancel"));
+        $template->set('delete', ($actionID == 'delete_folder_confirm') ? _("Delete Selected Folders") : '', true);
+        $template->set('empty', ($actionID == 'folders_empty_mailbox_confirm') ? _("Empty Selected Folders") : '', true);
+        $template->set('folders', $loop);
+        $template->set('folders_url', $folders_url);
+        echo $template->fetch(IMP_TEMPLATES . '/folders/folders_confirm.html');
+
+        require $registry->get('templates', 'horde') . '/common-footer.inc';
+        exit;
+    }
+    break;
 }
 
 /* Display the correct message on the action bar */
@@ -266,16 +295,9 @@ if (isset($quota)) {
     require IMP_TEMPLATES . '/quota/quota.inc';
 }
 
-/* Default to the very top of the hierarchy */
-if (!isset($pattern)) {
-    $pattern = '%';
-}
-
 $i = $rowct = 0;
 $displayNames = $newmsgs = array();
-$last_item = false;
 
-require_once IMP_TEMPLATES . '/folders/javascript.inc';
 if ($imp['file_upload'] && ($actionID == 'import_mbox')) {
     require IMP_TEMPLATES . '/folders/import.inc';
     require $registry->get('templates', 'horde') . '/common-footer.inc';
@@ -285,21 +307,13 @@ if ($imp['file_upload'] && ($actionID == 'import_mbox')) {
     require IMP_TEMPLATES . '/folders/actions.inc';
 }
 
-if ($showAll) {
-    $unsubList = $imp_folder->flistUnsubscribed_IMP();
-}
-
 /* Get special folders. */
-$trash = IMP::addPreambleString($prefs->getValue('trash_folder'));
-$draft = IMP::addPreambleString($prefs->getValue('drafts_folder'));
-$sent = $identity->getAll('sent_mail_folder');
-$sent = array_filter($sent, create_function('$mbox', 'return !empty($mbox);'));
-$sent = array_map(array('IMP', 'addPreambleString'), $sent);
+$trash = IMP::folderPref($prefs->getValue('trash_folder'), true);
+$draft = IMP::folderPref($prefs->getValue('drafts_folder'), true);
+$sent = $identity->getAllSentmailFolders();
 
 $name_url = Util::addParameter(Horde::applicationUrl('mailbox.php'), 'no_newmail_popup', 1);
 
-$prefix = $imptree->getPrefix();
-$notrail_prefix = $imptree->noTrailingDelimiter($prefix);
 $mbox_icons = $morembox = $rows = array();
 
 /* Call the mailbox icon hook, if requested. */
@@ -317,6 +331,7 @@ do {
     $row['show_msgs'] = false;
     $row['nocheckbox'] = false;
     $row['vfolder'] = false;
+    $mailbox['label'] = htmlspecialchars($mailbox['label']);
 
     if (!$imptree->isContainer($mailbox)) {
         /* We are dealing with mailboxes here.
@@ -338,7 +353,7 @@ do {
                 /* Highlight mailboxes with unread messages in bold. */
                 $row['new'] = $msgs_info['unseen'];
                 if (!empty($row['new'])) {
-                    $mailbox['label'] = '<b>' . $mailbox['label'] . '</b>';
+                    $mailbox['label'] = '<strong>' . $mailbox['label'] . '</strong>';
                 }
             }
         }
@@ -347,11 +362,11 @@ do {
 
         switch ($mailbox['value']) {
         case 'INBOX':
-            $dir2 = _image('inbox.png', _("INBOX"), 'folder');
+            $dir2 = _image('inbox.png', _("Inbox"), 'folder');
             break;
 
         case $trash:
-            $dir2 = _image('trash.png', _("Trash folder"), 'folder');
+            $dir2 = ($prefs->getValue('use_vtrash')) ? _image(($imptree->isOpen($mailbox)) ? 'folder_open.png' : 'folder.png', _("Mailbox"), 'folder') :_image('trash.png', _("Trash folder"), 'folder');
             break;
 
         case $draft:
@@ -365,7 +380,7 @@ do {
                 if (isset($mbox_icons[$mailbox['value']])) {
                     $dir2 = $mbox_icons[$mailbox['value']];
                 } else {
-                    $dir2 = _image('folder.png', _("Mailbox"), 'folder');
+                    $dir2 = _image(($imptree->isOpen($mailbox)) ? 'folder_open.png' : 'folder.png', _("Mailbox"), 'folder');
                 }
             }
             break;
@@ -373,10 +388,18 @@ do {
 
         /* Virtual folders. */
         if ($imptree->isVFolder($mailbox)) {
-            $row['vfolder'] = true;
             $row['nocheckbox'] = true;
-            $row['delvfolder'] = Horde::link(Util::addParameter($folders_url, array('actionID' => 'delete_vfolder', 'vfolder' => $mailbox['value'])), _("Delete Virtual Folder")) . _("Delete") . '</a>';
-            $row['editvfolder'] = Horde::link(Util::addParameter(Horde::applicationUrl('search.php'), array('edit_vfolder' => 1, 'vfolder' => $mailbox['value'])), _("Edit Virtual Folder")) . _("Edit") . '</a>';
+            if ($imp_search->isVTrashFolder($mailbox['value'])) {
+                $row['vfolder'] = false;
+                $dir2 = _image('trash.png', _("Virtual Trash Folder"), 'folder');
+            } elseif ($imp_search->isVINBOXFolder($mailbox['value'])) {
+                $row['vfolder'] = false;
+                $dir2 = _image('inbox.png', _("Virtual INBOX Folder"), 'folder');
+            } else {
+                $row['vfolder'] = true;
+                $row['delvfolder'] = Horde::link($imp_search->deleteURL($mailbox['value']), _("Delete Virtual Folder")) . _("Delete") . '</a>';
+                $row['editvfolder'] = Horde::link($imp_search->editURL($mailbox['value']), _("Edit Virtual Folder")) . _("Edit") . '</a>';
+            }
         }
     } else {
         /* We are dealing with folders here. */
@@ -408,60 +431,61 @@ do {
         } else {
             $dir = Util::addParameter($dir, 'actionID', 'expand_folder');
             if ($mailbox['value'] == 'INBOX') {
-                $plus_img = 'plusonly.png';
-                $last_item = true;
+                $plus_img = 'plustop.png';
             } else {
                 $plus_img = ($peek) ? 'plus.png' : 'plusbottom.png';
             }
             $dir = Horde::link($dir, _("Expand Folder")) . _image($plus_img, _("Expand"), 'tree') . "</a>$dir2";
         }
     } else {
-        $join_img = ($peek) ? 'join.png' : (($mailbox['value'] == 'INBOX') ? 'blank.png' : 'joinbottom.png');
+        if ($mailbox['value'] == 'INBOX') {
+            $join_img = ($peek) ? 'joinbottom-down.png' : 'blank.png';
+        } else {
+            $join_img = ($peek) ? 'join.png' : 'joinbottom.png';
+        }
         $dir = _image($join_img, '', 'tree') . $dir2;
     }
 
     /* Highlight line differently if folder/mailbox is
      * unsubscribed. */
-    $row['class'] = (++$rowct % 2) ? 'text' : 'item0';
-    if ($showAll && $subscribe && isset($unsubList[$mailbox['value']])) {
+    $row['class'] = (++$rowct % 2) ? 'item0' : 'item1';
+    if ($showAll && $subscribe && !$imptree->isSubscribed($mailbox) && !$imptree->isContainer($mailbox)) {
         $row['class'] .= ' folderunsub';
     }
 
-    /* The indent level of the current folder. */
-    $indent_level = $mailbox['level'];
-
-    /* If we have a folder prefix, shift each folder in the hierarchy
-     * up one level before showing it to the user. */
-    if (!empty($prefix) &&
-        ($mailbox['value'] != 'INBOX') &&
-        String::substr($mailbox['value'], 0, String::length($notrail_prefix)) == $notrail_prefix) {
-        $indent_level--;
-    }
-
     $row['mbox_val'] = htmlspecialchars($mailbox['value']);
-
     $row['line'] = '';
-    $morembox[$indent_level] = $peek;
-    for ($i = 0; $i < $indent_level; $i++) {
+    $morembox[$mailbox['level']] = $peek;
+    for ($i = 0; $i < $mailbox['level']; $i++) {
         $row['line'] .= _image(($morembox[$i]) ? 'line.png' : 'blank.png', '', 'tree');
     }
     $row['line'] .= $dir;
 
     /* Hide folder prefixes from the user. */
-    if ($indent_level >= 0) {
+    if ($mailbox['level'] >= 0) {
         $rows[] = $row;
         $displayNames[] = addslashes(IMP::displayFolder($mailbox['value']));
     }
 
-    if ($last_item) {
-        break;
-    }
 } while (($mailbox = $imptree->next()));
 
 /* Check to see if user wants new mail notification */
 if ($prefs->getValue('nav_popup')) {
     $notification->push(IMP::getNewMessagePopup($newmsgs), 'javascript');
 }
+if ($prefs->getValue('nav_audio')) {
+    $play = false;
+    foreach ($newmsgs as $mb => $nm) {
+        if ($nm > 0) {
+            $play = true;
+            break;
+        }
+    }
+    if ($play) {
+        $notification->push($registry->getImageDir() . '/audio/theetone.wav',
+                            'audio');
+    }
+}
 
 /* Render the rows now. */
 $template = &new Horde_Template();
@@ -476,15 +500,18 @@ require IMP_TEMPLATES . '/folders/foot.inc';
 
 if (!empty($open_compose_window)) {
     $args = 'popup=1';
-    if (isset($options)) {
-        foreach ($options as $arg => $value) {
-            $args .= !empty($value) ? '&' . $arg . '=' . urlencode($value) : '';
-        }
+    if (!isset($options)) {
+        $options = array();
     }
-    foreach (IMP::getComposeArgs() as $arg => $value) {
+    foreach (array_merge($options, IMP::getComposeArgs()) as $arg => $value) {
         $args .= !empty($value) ? '&' . $arg . '=' . urlencode($value) : '';
     }
-    echo "<script language='JavaScript' type='text/javascript'>open_compose_win('" . addslashes($args) . "'); focus_compose_win();</script>";
+    Horde::addScriptFile('popup.js');
+    echo "<script type='text/javascript'>popup_imp('" . Horde::applicationUrl('compose.php') . "',700,650,'" . addslashes($args) . "');</script>";
 }
 
+/* BC check. */
+if (class_exists('Notification_Listener_audio')) {
+    $notification->notify(array('listeners' => 'audio'));
+}
 require $registry->get('templates', 'horde') . '/common-footer.inc';
