@@ -6,7 +6,7 @@ require_once 'Horde/MIME/Viewer/html.php';
  * The MIME_Viewer_html class renders out HTML text with an effort to
  * remove potentially malicious code.
  *
- * $Horde: imp/lib/MIME/Viewer/html.php,v 1.75.2.25 2007/09/11 10:22:34 jan Exp $
+ * $Horde: imp/lib/MIME/Viewer/html.php,v 1.75.2.28 2007/11/22 15:45:22 jan Exp $
  *
  * Copyright 1999-2007 Anil Madhavapeddy <anil@recoil.org>
  * Copyright 1999-2007 Jon Parise <jon@recoil.org>
@@ -55,15 +55,22 @@ class IMP_MIME_Viewer_html extends MIME_Viewer_html {
          * that have an "#xyz" anchor and ignore all links that already have a
          * target. */
         $data = preg_replace(
-            array('|<a([^>]*\s+href=["\']?(#\|mailto:))|i',
-                  '|<a([^>]*)\s+target=["\']?[^>"\'\s]*["\']?|i',
-                  '|<a\s|i',
-                  "|\x01|"),
+             array('/<a\s([^>]*\s*href=["\']?(#|mailto:))/i',
+                  '/<a\s([^>]*)\s*target=["\']?[^>"\'\s]*["\']?/i',
+                  '/<a\s/i',
+                  '/<area\s([^>]*\s*href=["\']?(#|mailto:))/i',
+                  '/<area\s([^>]*)\s*target=["\']?[^>"\'\s]*["\']?/i',
+                  '/<area\s/i',
+                  "/\x01/",
+                  "/\x02/"),
             array("<\x01\\1",
-                  "<\x01\\1",
                   "<\x01 \\1 target=\"_blank\"",
                   '<a target="_blank" ',
-                  'a '),
+                  "<\x02\\1",
+                  "<\x02 \\1 target=\"_blank\"",
+                  '<area target="_blank" ',
+                  'a ',
+                  'area '),
             $data);
 
         /* Turn mailto: links into our own compose links. */
